fit_mult_impute_obs_outcome: Fit a model on multiply imputed data using only observations with non-missing
outcome(s)
Description
This function is a wrapper for fitting models with Hmisc::fit.mult.impute() on a
multiply imputed dataset generated with mice::mice(). Cases with a
missing outcome in the original dataset are removed from the mids object
by using the "subset" argument in Hmisc::fit.mult.impute().